genshi.template.directives.WhenDirective

Package genshi :: Package template :: Module directives :: Class WhenDirective |

# Class WhenDirective

    object --+
             |
     Directive --+
                 |
                WhenDirective

Implementation of the `py:when` directive for nesting in a parent with the `py:choose` directive.

See the documentation of the ChooseDirective for usage.

Nested Classes
Inherited from `Directive`: `__metaclass__`

Instance Methods
__init__(self, value, template, namespaces=None, lineno=-1, offset=-1) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__call__(self, stream, directives, ctxt, **vars) Apply the directive to the given stream. |
Inherited from `Directive`: `__repr__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Methods
attach(cls, template, stream, value, namespaces, pos) Called after the template stream has been completely parsed. |

Class Variables
| tagname = ``'``when``'``

Properties
| filename
Inherited from `Directive`: `expr` Inherited from `object`: `__class__`

Method Details

### __init__(self, value, template, namespaces=None, lineno=-1, offset=-1) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### attach(cls, template, stream, value, namespaces, pos) Class Method |
Called after the template stream has been completely parsed. This class method should return a `(directive, stream)` tuple. If `directive` is not `None`, it should be an instance of the Directive class, and gets added to the list of directives applied to the substream at runtime. `stream` is an event stream that replaces the original stream associated with the directive. Parameters: `template` - the Template object `stream` - the event stream associated with the directive `value` - the argument value for the directive; if the directive was specified as an element, this will be an Attrs instance with all specified attributes, otherwise it will be a `unicode` object with just the attribute value `namespaces` - a mapping of namespace URIs to prefixes `pos` - a `(filename, lineno, offset)` tuple describing the location where the directive was found in the source Overrides: Directive.attach (inherited documentation)

### __call__(self, stream, directives, ctxt, **vars) (Call operator) |
Apply the directive to the given stream. Parameters: `stream` - the event stream `directives` - a list of the remaining directives that should process the stream `ctxt` - the context data `vars` - additional variables that should be made available when Python code is executed Overrides: Directive.__call__ (inherited documentation)